Keen | Blog Post
Description: Blog post example

# Customer Relationship Management

New Order

### Blog Post

Reports

# Long term business aims and text objectives

Nov 18, 2018
By Admin
24 Comments

Apart from the objective of your text, your company or your website will have long term business objectives. You should think about those long term business aims while determining the objectives of the text on your website.

For instance, at Yoast.com, we write blogposts largely to inform people about SEO. So the objective is to inform people. However, we also want people to become return visitors and to gain trust in our brand. Eventually, the long term purpose of our informing blogs is to gain enough trust for people to buy one of our products.

Be aware that if the objective of your post is to generate links from others, you should think about the character of your post as well. If you want your post to attract links from other sites in order to improve your rankings in Google you should focus on writing informative or amusing posts. Persuasive posts, in which the sales arguments are salient, will not receive as many links as purely informative posts will. People are more likely to share an informative or an amusing post than a purely persuasive post, because these posts are more free of ulterior motives.

Jeremy Fisher, Author
Share this post:
38 Comments
Jeremy Fisher, 2 days ago
Reply

For instance, at Yoast.com, we write blogposts largely to inform people about SEO. So the objective is to inform people. However, we also want people to become return visitors and to gain trust in our brand.

Jeremy Fisher, 2 days ago
Reply

For instance, at Yoast.com, we write blogposts largely to inform people about SEO. So the objective is to inform people. However, we also want people to become return visitors and to gain trust in our brand.

Jeremy Fisher, 2 days ago
Reply

For instance, at Yoast.com, we write blogposts largely to inform people about SEO. So the objective is to inform people. However, we also want people to become return visitors and to gain trust in our brand.

### Quick Actions

Orders
Uploades
Products
Customers
Blog Posts
Settings
02:30 PM
KeenThemes created new layout whith tens of new options for Keen Admin panel
HTML,CSS,VueJS
01:20 AM
New secyrity alert by Firewall & order to take aktion on User Preferences
Security, Fieewall
Yestardey
FlyMore design mock-ups been uploadet by designers Bob, Naomi, Richard
PSD, Sketch, AJ
Aug 13,2018
Meeting with Ken Digital Corp ot Unit14, 3 Edigor Buildings, George Street, Loondon
England, BA12FJ
Meeting, Customer
May 09, 2018
KeenThemes created new layout whith tens of new options for Keen Admin panel
HTML,CSS,VueJS
01:20 AM
New secyrity alert by Firewall & order to take aktion on User Preferences
Security, Fieewall

### Recent Bills

Lorem Ipsum is simply dummy text of the printing and typesetting simply dummy text of the printing industry.
Dismiss View

### Latest Orders

Lorem Ipsum is simply dummy text of the printing and typesetting simply dummy text of the printing industry.
Dismiss View

### Latest Invoices

Lorem Ipsum is simply dummy text of the printing and typesetting simply dummy text of the printing industry.
Dismiss View

### New Comments

Lorem Ipsum is simply dummy text of the printing and typesetting simply dummy text of the printing industry.
Dismiss View

### Recent Posts

Lorem Ipsum is simply dummy text of the printing and typesetting simply dummy text of the printing industry.
Dismiss View
Notifications
Enable notifications:
Enable audit log:
Notify on new orders:
Orders
Enable order tracking:
Enable orders reports:
Allow order status auto update:
Customers
Enable customer singup:
Enable customers reporting:
Notifiy on new customer registration:

- Demos

### Select A Demo

Demo 1
Default RTL Version
Demo 2
Default RTL Version
Demo 3
Default RTL Version
Demo 4
Default RTL Version
Demo 5
Default RTL Version
Demo 6
Default RTL Version
Demo 7
Coming soon
Demo 8
Coming soon
Demo 9
Coming soon
Buy Keen Now!